@@ -7,13 +7,140 @@ set -o errexit
 # Baldur's Gate 3
 ###
 
-script_version=20231103.3
+script_version=20240106.1
 
 PLAYIT_COMPATIBILITY_LEVEL='2.27'
 
 GAME_ID='baldurs-gate-3'
 GAME_NAME='Baldurʼs Gate Ⅲ'
 
+ARCHIVE_BASE_PATCH5_0_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888).exe'
+ARCHIVE_BASE_PATCH5_0_MD5='6862e7a492de45b737d78e08c281a511'
+ARCHIVE_BASE_PATCH5_0_TYPE='innosetup'
+ARCHIVE_BASE_PATCH5_0_PART1_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-1.bin'
+ARCHIVE_BASE_PATCH5_0_PART1_MD5='186c358ea2dc870e028ec0673a6365e3'
+ARCHIVE_BASE_PATCH5_0_PART2_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-2.bin'
+ARCHIVE_BASE_PATCH5_0_PART2_MD5='5cce05c8723bed050cda429c0f6c04e1'
+ARCHIVE_BASE_PATCH5_0_PART3_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-3.bin'
+ARCHIVE_BASE_PATCH5_0_PART3_MD5='d83a39fcd16e69d1279f265b4f01f9b5'
+ARCHIVE_BASE_PATCH5_0_PART4_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-4.bin'
+ARCHIVE_BASE_PATCH5_0_PART4_MD5='66d9b2aebad820e832e831634c0a7330'
+ARCHIVE_BASE_PATCH5_0_PART5_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-5.bin'
+ARCHIVE_BASE_PATCH5_0_PART5_MD5='68c8cdafb45c97a0cd1690d168862100'
+ARCHIVE_BASE_PATCH5_0_PART6_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-6.bin'
+ARCHIVE_BASE_PATCH5_0_PART6_MD5='1f70e6253abca8e03b16e9249ce4debd'
+ARCHIVE_BASE_PATCH5_0_PART7_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-7.bin'
+ARCHIVE_BASE_PATCH5_0_PART7_MD5='46af9f6c04b624c5049beee3dffc9696'
+ARCHIVE_BASE_PATCH5_0_PART8_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-8.bin'
+ARCHIVE_BASE_PATCH5_0_PART8_MD5='8f746939ff4e6407b78aa2f43dfc6392'
+ARCHIVE_BASE_PATCH5_0_PART9_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-9.bin'
+ARCHIVE_BASE_PATCH5_0_PART9_MD5='758b43451029e2f63ed1dbb9c987461b'
+ARCHIVE_BASE_PATCH5_0_PART10_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-10.bin'
+ARCHIVE_BASE_PATCH5_0_PART10_MD5='5d19fc102d11834f08cf6c1f0b925ea0'
+ARCHIVE_BASE_PATCH5_0_PART11_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-11.bin'
+ARCHIVE_BASE_PATCH5_0_PART11_MD5='a34ccbb9196795da458df88d16f29001'
+ARCHIVE_BASE_PATCH5_0_PART12_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-12.bin'
+ARCHIVE_BASE_PATCH5_0_PART12_MD5='4a0b02ed0fe0e213050ba36ca2c1e9bf'
+ARCHIVE_BASE_PATCH5_0_PART13_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-13.bin'
+ARCHIVE_BASE_PATCH5_0_PART13_MD5='4bba114b9fd38dc3b0c15aee4a7badc7'
+ARCHIVE_BASE_PATCH5_0_PART14_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-14.bin'
+ARCHIVE_BASE_PATCH5_0_PART14_MD5='26fab2816e6a90c46b26666a6c9825cc'
+ARCHIVE_BASE_PATCH5_0_PART15_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-15.bin'
+ARCHIVE_BASE_PATCH5_0_PART15_MD5='0c2e8f809fce1dc30d003512eeb9bdf5'
+ARCHIVE_BASE_PATCH5_0_PART16_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-16.bin'
+ARCHIVE_BASE_PATCH5_0_PART16_MD5='eb11c87799b0870c09dff97cd7d5d721'
+ARCHIVE_BASE_PATCH5_0_PART17_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-17.bin'
+ARCHIVE_BASE_PATCH5_0_PART17_MD5='679670d1c9e4b80cc4b7e1e8cd46b24a'
+ARCHIVE_BASE_PATCH5_0_PART18_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-18.bin'
+ARCHIVE_BASE_PATCH5_0_PART18_MD5='c01feb0bdf8b7677af42575c16cea2b3'
+ARCHIVE_BASE_PATCH5_0_PART19_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-19.bin'
+ARCHIVE_BASE_PATCH5_0_PART19_MD5='7f9b210f8afc3320bead9637edb882ac'
+ARCHIVE_BASE_PATCH5_0_PART20_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-20.bin'
+ARCHIVE_BASE_PATCH5_0_PART20_MD5='b4bc49e1a36c10cf1ad64665300f3d3a'
+ARCHIVE_BASE_PATCH5_0_PART21_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-21.bin'
+ARCHIVE_BASE_PATCH5_0_PART21_MD5='aa7c335e7ffc0bcda16d19817e7d2e32'
+ARCHIVE_BASE_PATCH5_0_PART22_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-22.bin'
+ARCHIVE_BASE_PATCH5_0_PART22_MD5='5d6cef68c2e0067d2aac4b891ddc15fe'
+ARCHIVE_BASE_PATCH5_0_PART23_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-23.bin'
+ARCHIVE_BASE_PATCH5_0_PART23_MD5='b7596a74a8d17ba53041f4cb65e7c275'
+ARCHIVE_BASE_PATCH5_0_PART24_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-24.bin'
+ARCHIVE_BASE_PATCH5_0_PART24_MD5='ee7278a6d7ddc74f9e84350c007d83f4'
+ARCHIVE_BASE_PATCH5_0_PART25_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-25.bin'
+ARCHIVE_BASE_PATCH5_0_PART25_MD5='5f53ee4b9c609e0e2033c24349c7c08f'
+ARCHIVE_BASE_PATCH5_0_PART26_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-26.bin'
+ARCHIVE_BASE_PATCH5_0_PART26_MD5='8bcc1faddcc9dbaea2181d6407944e91'
+ARCHIVE_BASE_PATCH5_0_PART27_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-27.bin'
+ARCHIVE_BASE_PATCH5_0_PART27_MD5='4be5806c0d26719004cf3c7f447a9adb'
+ARCHIVE_BASE_PATCH5_0_PART28_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-28.bin'
+ARCHIVE_BASE_PATCH5_0_PART28_MD5='2acf6acde88c6c7e38d2d018b9777321'
+ARCHIVE_BASE_PATCH5_0_PART29_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-29.bin'
+ARCHIVE_BASE_PATCH5_0_PART29_MD5='c02adb5c2f3492580e4b2264d678bbec'
+ARCHIVE_BASE_PATCH5_0_PART30_NAME='setup_baldurs_gate_3_release_-_v4.1.1.4251417_patch5_hotfix4__japanese_(64bit)_(69888)-30.bin'
+ARCHIVE_BASE_PATCH5_0_PART30_MD5='9d686af3f1622d30a4636d97614a0e12'
+ARCHIVE_BASE_PATCH5_0_SIZE='144082412'
+ARCHIVE_BASE_PATCH5_0_VERSION='4.1.1.4251417-gog69888'
+ARCHIVE_BASE_PATCH5_0_URL='https://www.gog.com/game/baldurs_gate_iii'
+
+ARCHIVE_BASE_PATCH4_0_NAME='setup_baldurs_gate_3_release_-_v4.1.1.3956130_-_patch_patch4_hotfix3__(64bit)_(68995).exe'
+ARCHIVE_BASE_PATCH4_0_MD5='ab6267432b272ff880127131e7b2f5f3'
+ARCHIVE_BASE_PATCH4_0_TYPE='innosetup'
+ARCHIVE_BASE_PATCH4_0_PART1_NAME='setup_baldurs_gate_3_release_-_v4.1.1.3956130_-_patch_patch4_hotfix3__(64bit)_(68995)-1.bin'
+ARCHIVE_BASE_PATCH4_0_PART1_MD5='df12c48514a6e053123b993536984db1'
+ARCHIVE_BASE_PATCH4_0_PART2_NAME='setup_baldurs_gate_3_release_-_v4.1.1.3956130_-_patch_patch4_hotfix3__(64bit)_(68995)-2.bin'
+ARCHIVE_BASE_PATCH4_0_PART2_MD5='7624eae52e3ba390cc451c92eb22971e'
+ARCHIVE_BASE_PATCH4_0_PART3_NAME='setup_baldurs_gate_3_release_-_v4.1.1.3956130_-_patch_patch4_hotfix3__(64bit)_(68995)-3.bin'
+ARCHIVE_BASE_PATCH4_0_PART3_MD5='55926fedfbe8bfc55259f43e279506c2'
+ARCHIVE_BASE_PATCH4_0_PART4_NAME='setup_baldurs_gate_3_release_-_v4.1.1.3956130_-_patch_patch4_hotfix3__(64bit)_(68995)-4.bin'
+ARCHIVE_BASE_PATCH4_0_PART4_MD5='6521b33ac90d7da85737fd789a035a4b'
+ARCHIVE_BASE_PATCH4_0_PART5_NAME='setup_baldurs_gate_3_release_-_v4.1.1.3956130_-_patch_patch4_hotfix3__(64bit)_(68995)-5.bin'
+ARCHIVE_BASE_PATCH4_0_PART5_MD5='9cab7eb4d37f6970d7c75620604f6260'
+ARCHIVE_BASE_PATCH4_0_PART6_NAME='setup_baldurs_gate_3_release_-_v4.1.1.3956130_-_patch_patch4_hotfix3__(64bit)_(68995)-6.bin'
+ARCHIVE_BASE_PATCH4_0_PART6_MD5='d6c465c93781fe3ff757c6c20a2ff373'
+ARCHIVE_BASE_PATCH4_0_PART7_NAME='setup_baldurs_gate_3_release_-_v4.1.1.3956130_-_patch_patch4_hotfix3__(64bit)_(68995)-7.bin'
+ARCHIVE_BASE_PATCH4_0_PART7_MD5='75a4703c4ab50e922f35c37dc0b2f91c'
+ARCHIVE_BASE_PATCH4_0_PART8_NAME='setup_baldurs_gate_3_release_-_v4.1.1.3956130_-_patch_patch4_hotfix3__(64bit)_(68995)-8.bin'
+ARCHIVE_BASE_PATCH4_0_PART8_MD5='2abf5bf419d07af67fa89ab9cf782401'
+ARCHIVE_BASE_PATCH4_0_PART9_NAME='setup_baldurs_gate_3_release_-_v4.1.1.3956130_-_patch_patch4_hotfix3__(64bit)_(68995)-9.bin'
+ARCHIVE_BASE_PATCH4_0_PART9_MD5='156c9711f63b8db03f31e41fd22e59af'
+ARCHIVE_BASE_PATCH4_0_PART10_NAME='setup_baldurs_gate_3_release_-_v4.1.1.3956130_-_patch_patch4_hotfix3__(64bit)_(68995)-10.bin'
+ARCHIVE_BASE_PATCH4_0_PART10_MD5='32430ec83c9b780c637c1d6b2de9ce68'
+ARCHIVE_BASE_PATCH4_0_PART11_NAME='setup_baldurs_gate_3_release_-_v4.1.1.3956130_-_patch_patch4_hotfix3__(64bit)_(68995)-11.bin'
+ARCHIVE_BASE_PATCH4_0_PART11_MD5='d0ae7f626c2f163f7192f2e6d10f09db'
+ARCHIVE_BASE_PATCH4_0_PART12_NAME='setup_baldurs_gate_3_release_-_v4.1.1.3956130_-_patch_patch4_hotfix3__(64bit)_(68995)-12.bin'
+ARCHIVE_BASE_PATCH4_0_PART12_MD5='5378372fae1cf46669db85f60091e77c'
+ARCHIVE_BASE_PATCH4_0_PART13_NAME='setup_baldurs_gate_3_release_-_v4.1.1.3956130_-_patch_patch4_hotfix3__(64bit)_(68995)-13.bin'
+ARCHIVE_BASE_PATCH4_0_PART13_MD5='f0e0d239c05867ceddd2f630794db82f'
+ARCHIVE_BASE_PATCH4_0_PART14_NAME='setup_baldurs_gate_3_release_-_v4.1.1.3956130_-_patch_patch4_hotfix3__(64bit)_(68995)-14.bin'
+ARCHIVE_BASE_PATCH4_0_PART14_MD5='49324f1d65939e8e41ea5530f369d5cd'
+ARCHIVE_BASE_PATCH4_0_PART15_NAME='setup_baldurs_gate_3_release_-_v4.1.1.3956130_-_patch_patch4_hotfix3__(64bit)_(68995)-15.bin'
+ARCHIVE_BASE_PATCH4_0_PART15_MD5='a6547b00be69663430c8c72bfa4a9f85'
+ARCHIVE_BASE_PATCH4_0_PART16_NAME='setup_baldurs_gate_3_release_-_v4.1.1.3956130_-_patch_patch4_hotfix3__(64bit)_(68995)-16.bin'
+ARCHIVE_BASE_PATCH4_0_PART16_MD5='c285e952585a260478c2d31f29448745'
+ARCHIVE_BASE_PATCH4_0_PART17_NAME='setup_baldurs_gate_3_release_-_v4.1.1.3956130_-_patch_patch4_hotfix3__(64bit)_(68995)-17.bin'
+ARCHIVE_BASE_PATCH4_0_PART17_MD5='d6fb24e9f9781f4f72c5435634ac6ac7'
+ARCHIVE_BASE_PATCH4_0_PART18_NAME='setup_baldurs_gate_3_release_-_v4.1.1.3956130_-_patch_patch4_hotfix3__(64bit)_(68995)-18.bin'
+ARCHIVE_BASE_PATCH4_0_PART18_MD5='c05f0ef6d178843fb0da80753752b5b5'
+ARCHIVE_BASE_PATCH4_0_PART19_NAME='setup_baldurs_gate_3_release_-_v4.1.1.3956130_-_patch_patch4_hotfix3__(64bit)_(68995)-19.bin'
+ARCHIVE_BASE_PATCH4_0_PART19_MD5='626615ae36a91d6f06b66f82090725e7'
+ARCHIVE_BASE_PATCH4_0_PART20_NAME='setup_baldurs_gate_3_release_-_v4.1.1.3956130_-_patch_patch4_hotfix3__(64bit)_(68995)-20.bin'
+ARCHIVE_BASE_PATCH4_0_PART20_MD5='e41563ed5af9e65893968dc4f3a3a11f'
+ARCHIVE_BASE_PATCH4_0_PART21_NAME='setup_baldurs_gate_3_release_-_v4.1.1.3956130_-_patch_patch4_hotfix3__(64bit)_(68995)-21.bin'
+ARCHIVE_BASE_PATCH4_0_PART21_MD5='f8c9ca01fa54f40c6720907a6754497c'
+ARCHIVE_BASE_PATCH4_0_PART22_NAME='setup_baldurs_gate_3_release_-_v4.1.1.3956130_-_patch_patch4_hotfix3__(64bit)_(68995)-22.bin'
+ARCHIVE_BASE_PATCH4_0_PART22_MD5='6c73b251f90ccdfc3478e36dd5c10ba2'
+ARCHIVE_BASE_PATCH4_0_PART23_NAME='setup_baldurs_gate_3_release_-_v4.1.1.3956130_-_patch_patch4_hotfix3__(64bit)_(68995)-23.bin'
+ARCHIVE_BASE_PATCH4_0_PART23_MD5='1b3b77c0ec4d9d0355964662ff82c9eb'
+ARCHIVE_BASE_PATCH4_0_PART24_NAME='setup_baldurs_gate_3_release_-_v4.1.1.3956130_-_patch_patch4_hotfix3__(64bit)_(68995)-24.bin'
+ARCHIVE_BASE_PATCH4_0_PART24_MD5='49538632c8eb659f017c3ae1a1698a1f'
+ARCHIVE_BASE_PATCH4_0_PART25_NAME='setup_baldurs_gate_3_release_-_v4.1.1.3956130_-_patch_patch4_hotfix3__(64bit)_(68995)-25.bin'
+ARCHIVE_BASE_PATCH4_0_PART25_MD5='6ee062ce652cb6606b9747f3ace8706e'
+ARCHIVE_BASE_PATCH4_0_PART26_NAME='setup_baldurs_gate_3_release_-_v4.1.1.3956130_-_patch_patch4_hotfix3__(64bit)_(68995)-26.bin'
+ARCHIVE_BASE_PATCH4_0_PART26_MD5='97fda2b27e9bf32387e17294f2dd05ed'
+ARCHIVE_BASE_PATCH4_0_PART27_NAME='setup_baldurs_gate_3_release_-_v4.1.1.3956130_-_patch_patch4_hotfix3__(64bit)_(68995)-27.bin'
+ARCHIVE_BASE_PATCH4_0_PART27_MD5='c4e2eee7ea51aa41ba1fcd2544a7423c'
+ARCHIVE_BASE_PATCH4_0_SIZE='126864164'
+ARCHIVE_BASE_PATCH4_0_VERSION='4.1.1.3956130-gog68995'
+
 ARCHIVE_BASE_PATCH3_0_NAME='setup_baldurs_gate_3_release_-_v4.1.1.3767641_-_patch_patch3_hotfix3__(64bit)_(68008).exe'
 ARCHIVE_BASE_PATCH3_0_MD5='e2da307eb714d2e746048e8fb7d646a4'
 ARCHIVE_BASE_PATCH3_0_TYPE='innosetup'
@@ -81,7 +208,6 @@ ARCHIVE_BASE_PATCH3_0_PART31_NAME='setup_baldurs_gate_3_release_-_v4.1.1.3767641
 ARCHIVE_BASE_PATCH3_0_PART31_MD5='5fb4854aaac674f56a563dc4616b8792'
 ARCHIVE_BASE_PATCH3_0_SIZE='156835644'
 ARCHIVE_BASE_PATCH3_0_VERSION='4.1.1.3767641-gog68008'
-ARCHIVE_BASE_PATCH3_0_URL='https://www.gog.com/game/baldurs_gate_iii'
 
 ARCHIVE_BASE_PATCH2_0_NAME='setup_baldurs_gate_3_release_-_v4.1.1.3700362_-_patch_patch2_hotfix2__(64bit)_(67336).exe'
 ARCHIVE_BASE_PATCH2_0_MD5='6eeac06fdc264d09052dd52a5d8f85fb'
@@ -284,7 +410,6 @@ data/localization/french'
 CONTENT_GAME_DATA_MODELS_FILES='
 data/models.pak'
 CONTENT_GAME_DATA_SOUNDS_FILES='
-data/sharedsounds.pak
 data/sharedsoundbanks.pak'
 CONTENT_GAME_DATA_TEXTURES_1_FILES='
 data/gustav_textures.pak
@@ -321,6 +446,8 @@ data/virtualtextures_16.pak'
 CONTENT_GAME_DATA_TEXTURES_11_FILES='
 data/virtualtextures_17.pak
 data/virtualtextures_18.pak'
+CONTENT_GAME_DATA_TEXTURES_12_FILES='
+data/virtualtextures_*.pak'
 CONTENT_GAME_DATA_PATCH0_FILES='
 data/patch0_hotfix*.pak'
 CONTENT_GAME_DATA_PATCH1_FILES='
@@ -330,6 +457,10 @@ data/patch2.pak
 data/patch2_hotfix*.pak'
 CONTENT_GAME_DATA_PATCH3_FILES='
 data/patch3_hotfix*.pak'
+CONTENT_GAME_DATA_PATCH4_FILES='
+data/patch4_hotfix*.pak'
+CONTENT_GAME_DATA_PATCH5_FILES='
+data/patch5_hotfix*.pak'
 CONTENT_GAME_DATA_FILES='
 data/assets.pak
 data/day0.pak
@@ -348,6 +479,12 @@ data/shared.pak'
 
 HUGE_FILES_DATA='
 data/gustav.pak'
+## The size of sharedsounds.pak goes over the .deb size limit only with patch 5,
+## but ./play.it has no problem "splitting" a file into a single chunk, at the cost of more time spent in post-install scripts.
+## TODO: The library-side implementation of huge files should probably skip files under the size limit,
+##       putting the whole file into a dedicated package without "splitting" it into a single chunk first.
+HUGE_FILES_DATA_SOUNDS='
+data/sharedsounds.pak'
 ## The _PATCH3 suffix is doubled so this matches:
 ## PKG_DATA_PATCH3 in the context of ARCHIVE_BASE_PATCH3
 ## but does not match:
@@ -386,19 +523,22 @@ PKG_DATA_TEXTURES_8
 PKG_DATA_TEXTURES_9
 PKG_DATA_TEXTURES_10
 PKG_DATA_TEXTURES_11
+PKG_DATA_TEXTURES_12
 PKG_DATA'
-PACKAGES_LIST_PATCH0="
-PKG_DATA_PATCH0
-$PACKAGES_LIST_BASE"
-PACKAGES_LIST_PATCH1="
-PKG_DATA_PATCH1
-$PACKAGES_LIST_PATCH0"
-PACKAGES_LIST_PATCH2="
-PKG_DATA_PATCH2
-$PACKAGES_LIST_PATCH1"
-PACKAGES_LIST_PATCH3="
-PKG_DATA_PATCH3
-$PACKAGES_LIST_PATCH2"
+PACKAGES_LIST_PATCH0="$PACKAGES_LIST_BASE
+PKG_DATA_PATCH0"
+PACKAGES_LIST_PATCH1="$PACKAGES_LIST_PATCH0
+PKG_DATA_PATCH1"
+PACKAGES_LIST_PATCH2="$PACKAGES_LIST_PATCH1
+PKG_DATA_PATCH2"
+PACKAGES_LIST_PATCH3="$PACKAGES_LIST_PATCH2
+PKG_DATA_PATCH3"
+## Archives patch0*.pak, patch1*.pak, patch2*.pak and patch3*.pak are dropped with the patch 4 release.
+PACKAGES_LIST_PATCH4="$PACKAGES_LIST_BASE
+PKG_DATA_PATCH4"
+## Archives patch4*.pak are dropped with the patch 5 release.
+PACKAGES_LIST_PATCH5="$PACKAGES_LIST_BASE
+PKG_DATA_PATCH5"
 
 PKG_L10N_COMMON_ID="${GAME_ID}-l10n-common"
 PKG_L10N_COMMON_DESCRIPTION='localizations - shared files'
@@ -442,6 +582,7 @@ PKG_DATA_TEXTURES_8_ID="${PKG_DATA_TEXTURES_ID}-8"
 PKG_DATA_TEXTURES_9_ID="${PKG_DATA_TEXTURES_ID}-9"
 PKG_DATA_TEXTURES_10_ID="${PKG_DATA_TEXTURES_ID}-10"
 PKG_DATA_TEXTURES_11_ID="${PKG_DATA_TEXTURES_ID}-11"
+PKG_DATA_TEXTURES_12_ID="${PKG_DATA_TEXTURES_ID}-12"
 PKG_DATA_TEXTURES_DESCRIPTION="$PKG_DATA_DESCRIPTION - textures"
 PKG_DATA_TEXTURES_1_DESCRIPTION="$PKG_DATA_TEXTURES_DESCRIPTION - 1"
 PKG_DATA_TEXTURES_2_DESCRIPTION="$PKG_DATA_TEXTURES_DESCRIPTION - 2"
@@ -454,20 +595,50 @@ PKG_DATA_TEXTURES_8_DESCRIPTION="$PKG_DATA_TEXTURES_DESCRIPTION - 8"
 PKG_DATA_TEXTURES_9_DESCRIPTION="$PKG_DATA_TEXTURES_DESCRIPTION - 9"
 PKG_DATA_TEXTURES_10_DESCRIPTION="$PKG_DATA_TEXTURES_DESCRIPTION - 10"
 PKG_DATA_TEXTURES_11_DESCRIPTION="$PKG_DATA_TEXTURES_DESCRIPTION - 11"
-PKG_DATA_DEPS="${PKG_DATA_DEPS:-} $PKG_DATA_TEXTURES_1_ID $PKG_DATA_TEXTURES_2_ID $PKG_DATA_TEXTURES_3_ID $PKG_DATA_TEXTURES_4_ID $PKG_DATA_TEXTURES_5_ID $PKG_DATA_TEXTURES_6_ID $PKG_DATA_TEXTURES_7_ID $PKG_DATA_TEXTURES_8_ID $PKG_DATA_TEXTURES_9_ID $PKG_DATA_TEXTURES_10_ID $PKG_DATA_TEXTURES_11_ID"
+PKG_DATA_TEXTURES_12_DESCRIPTION="$PKG_DATA_TEXTURES_DESCRIPTION - 12"
+PKG_DATA_DEPS="${PKG_DATA_DEPS:-} $PKG_DATA_TEXTURES_1_ID $PKG_DATA_TEXTURES_2_ID $PKG_DATA_TEXTURES_3_ID $PKG_DATA_TEXTURES_4_ID $PKG_DATA_TEXTURES_5_ID $PKG_DATA_TEXTURES_6_ID $PKG_DATA_TEXTURES_7_ID $PKG_DATA_TEXTURES_8_ID $PKG_DATA_TEXTURES_9_ID $PKG_DATA_TEXTURES_10_ID $PKG_DATA_TEXTURES_11_ID $PKG_DATA_TEXTURES_12_ID"
+## Only 11 texture packages are required prior to patch 5.
+PACKAGES_LIST_PATCH4=$(printf '%s' "$PACKAGES_LIST_PATCH4" | grep --invert-match 'PKG_DATA_TEXTURES_12')
+PACKAGES_LIST_PATCH3="$PACKAGES_LIST_PATCH4"
+PACKAGES_LIST_PATCH2="$PACKAGES_LIST_PATCH4"
+PACKAGES_LIST_PATCH1="$PACKAGES_LIST_PATCH4"
+PACKAGES_LIST_PATCH0="$PACKAGES_LIST_PATCH4"
+PKG_DATA_TEXTURES_11_PROVIDES_PATCH4="${PKG_DATA_TEXTURES_11_PROVIDES:-}
+$PKG_DATA_TEXTURES_12_ID"
+PKG_DATA_TEXTURES_11_PROVIDES_PATCH3="$PKG_DATA_TEXTURES_11_PROVIDES_PATCH4"
+PKG_DATA_TEXTURES_11_PROVIDES_PATCH2="$PKG_DATA_TEXTURES_11_PROVIDES_PATCH4"
+PKG_DATA_TEXTURES_11_PROVIDES_PATCH1="$PKG_DATA_TEXTURES_11_PROVIDES_PATCH4"
+PKG_DATA_TEXTURES_11_PROVIDES_PATCH0="$PKG_DATA_TEXTURES_11_PROVIDES_PATCH4"
 
 PKG_DATA_PATCH0_ID="${PKG_DATA_ID}-patch0"
 PKG_DATA_PATCH1_ID="${PKG_DATA_ID}-patch1"
 PKG_DATA_PATCH2_ID="${PKG_DATA_ID}-patch2"
 PKG_DATA_PATCH3_ID="${PKG_DATA_ID}-patch3"
+PKG_DATA_PATCH4_ID="${PKG_DATA_ID}-patch4"
+PKG_DATA_PATCH5_ID="${PKG_DATA_ID}-patch5"
 PKG_DATA_PATCH0_DESCRIPTION="$PKG_DATA_DESCRIPTION - patch0"
 PKG_DATA_PATCH1_DESCRIPTION="$PKG_DATA_DESCRIPTION - patch1"
 PKG_DATA_PATCH2_DESCRIPTION="$PKG_DATA_DESCRIPTION - patch2"
 PKG_DATA_PATCH3_DESCRIPTION="$PKG_DATA_DESCRIPTION - patch3"
+PKG_DATA_PATCH4_DESCRIPTION="$PKG_DATA_DESCRIPTION - patch4"
+PKG_DATA_PATCH5_DESCRIPTION="$PKG_DATA_DESCRIPTION - patch5"
 PKG_DATA_DEPS_PATCH0="${PKG_DATA_DEPS:-} $PKG_DATA_PATCH0_ID"
 PKG_DATA_DEPS_PATCH1="$PKG_DATA_DEPS_PATCH0 $PKG_DATA_PATCH1_ID"
 PKG_DATA_DEPS_PATCH2="$PKG_DATA_DEPS_PATCH1 $PKG_DATA_PATCH2_ID"
 PKG_DATA_DEPS_PATCH3="$PKG_DATA_DEPS_PATCH2 $PKG_DATA_PATCH3_ID"
+PKG_DATA_DEPS_PATCH4="${PKG_DATA_DEPS:-} $PKG_DATA_PATCH4_ID"
+PKG_DATA_DEPS_PATCH5="${PKG_DATA_DEPS:-} $PKG_DATA_PATCH5_ID"
+## Archives patch0*.pak, patch1*.pak, patch2*.pak and patch3*.pak are dropped with the patch 4 release.
+PKG_DATA_PATCH4_PROVIDES="
+$PKG_DATA_PATCH0_ID
+$PKG_DATA_PATCH1_ID
+$PKG_DATA_PATCH2_ID
+$PKG_DATA_PATCH3_ID
+${PKG_DATA_PATCH3_ID}-chunk1
+${PKG_DATA_PATCH3_ID}-chunk2"
+## Archives patch4*.pak are dropped with the patch 5 release.
+PKG_DATA_PATCH5_PROVIDES="$PKG_DATA_PATCH4_PROVIDES
+$PKG_DATA_PATCH4_ID"
 
 PKG_BIN_ARCH='64'
 PKG_BIN_DEPS="$PKG_L10N_ID $PKG_DATA_ID"
@@ -547,10 +718,10 @@ esac
 printf '\n'
 ## English localization
 printf "$message" "$lang_en"
-print_instructions $(packages_get_list | sed 's/PKG_L10N_FR//')
+print_instructions $(packages_list | sed 's/PKG_L10N_FR//')
 ## French localization
 printf "$message" "$lang_fr"
-print_instructions $(packages_get_list | sed 's/PKG_L10N_EN//')
+print_instructions $(packages_list | sed 's/PKG_L10N_EN//')
 
 # Clean up
 
