@@ -7,13 +7,22 @@ set -o errexit
 # Grim Dawn
 ###
 
-script_version=20121122.1
+script_version=20231211.1
 
 PLAYIT_COMPATIBILITY_LEVEL='2.27'
 
 GAME_ID='grim-dawn'
 GAME_NAME='Grim Dawn'
 
+ARCHIVE_BASE_3_NAME='setup_grim_dawn_1.2.0.3_hotfix_3_(64bit)_(69499).exe'
+ARCHIVE_BASE_3_MD5='d407d7f0c13b2e9a09c9d507a6dd9406'
+ARCHIVE_BASE_3_TYPE='innosetup'
+ARCHIVE_BASE_3_PART1_NAME='setup_grim_dawn_1.2.0.3_hotfix_3_(64bit)_(69499)-1.bin'
+ARCHIVE_BASE_3_PART1_MD5='cb0b21ec562a0023650928cabd3f2aac'
+ARCHIVE_BASE_3_SIZE='4716376'
+ARCHIVE_BASE_3_VERSION='1.2.0.3-gog69499'
+ARCHIVE_BASE_3_URL='https://www.gog.com/game/grim_dawn'
+
 ARCHIVE_BASE_2_NAME='setup_grim_dawn_1.2.0.2_hotfix_2_(64bit)_(69134).exe'
 ARCHIVE_BASE_2_MD5='a86614183a27085a644642e73c89dc31'
 ARCHIVE_BASE_2_TYPE='innosetup'
@@ -21,7 +30,6 @@ ARCHIVE_BASE_2_PART1_NAME='setup_grim_dawn_1.2.0.2_hotfix_2_(64bit)_(69134)-1.bi
 ARCHIVE_BASE_2_PART1_MD5='d4088f8591111a2aa1c5af081179ec38'
 ARCHIVE_BASE_2_SIZE='4414600'
 ARCHIVE_BASE_2_VERSION='1.2.0.2-gog69134'
-ARCHIVE_BASE_2_URL='https://www.gog.com/game/grim_dawn'
 
 ARCHIVE_BASE_1_NAME='setup_grim_dawn_1.2.0.1_hotfix_1_(64bit)_(69098).exe'
 ARCHIVE_BASE_1_MD5='0b4edacfee791cc6d83af7a2c36cb11c'
@@ -101,7 +109,7 @@ archive_extraction_default
 (
 	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"
 
-	# Delete unwanted files
+	## Delete unwanted files.
 	rm --recursive \
 		'__redist' \
 		'app' \
